//  NFCApi.h
//  Created by Robin on 2016. 5. 11..

#import "SDeviceApi.h"
@interface ComboNFCApi : SDeviceApi
+ (id)  sharedInstance;

/**
 *  @brief      Send the "Send Raw Data" command to the reader
 *  @details    Send "Send Raw Data" command including "sendData"
 *  @param      sendData : Byte type data
 *  @param      nLen : Length of sendData
 *  @return     YES
 */
- (BOOL) sendRawData:(Byte*)sendData len:(int)nLen;

/**
 *  @brief      Send the "Set Inventory" command to the reader
 *  @details
 *  @param      fInventoryTime :Not use
 *  @return     YES
 *  @bug        Not use parameter
 *  @todo       Will modify.
 */
- (BOOL) setInventory:(float)fInventoryTime;

/**
 *  @brief      NFC Start Sacn
 *  @details    Start an tag(NFC) read operation, tag IDs are sent back to user though notification packet.
 *  @return     YES
 */
- (BOOL) startScan;


/**
 *  @brief      NFC Stop Scan
 *  @details    Stop an read operation
 *  @return     YES
 */
- (BOOL) stopScan;

#pragma mark -- ISO15693 Function --
/**
 *  @brief      Send the "Read Multi Block" command to the reader.
 *  @details    指定された UID を持つ IC タグメモリ上の連続した複数ブロックのデータを読み出す.
 *  @param      index : 最初に読み出すブロック番号(0~255).
 *  @param      count : 読み出すブロック数(0~255).
 *  @return     YES or NO.
 */
- (BOOL)readMultiBlockWithBlockIndex:(int)index
                               count:(int)count;

/**
 *  @brief      Send the "Write Single Block" command to the reader.
 *  @details    指定された UID を持つ IC タグのメモリ上の指定したブロックへデータを書き込む.
 *  @param      index : ブロック番号(0~255).
 *  @param      writeData : 書き込むデータ(ブロックサイズが4バイトの場合).
 *  @param      uid : UID(オプションフラグの UID が「1」の時のみ付加(下位バイトから)).
 *  @return     YES or NO.
 */
- (BOOL)writeSingleBlockWithBlockIndex:(int)index
                             writeData:(NSData *)writeData
                                   uid:(NSData *)uid;

/**
 *  @brief      Send the "Write Bytes" command to the reader.
 *  @details    指定された UID を持つ指定ブロックから指定バイト数のデータを書き込む
 ※ タグへのデータの書き込みはブロック単位に行われます。 書き込むデータ長(データのバイト数)がブロックサイズに満たない場合、書き込まれる最終 ブロックのデータは、最後に「0x00」が付加され書き込まれます。
 *  @param      index : ブロック番号(0~255).
 *  @param      writeData : 書き込むデータ(ブロックサイズが4バイトの場合).
 *  @param      uid : UID(オプションフラグの UID が「1」の時のみ付加(下位バイトから)).
 *  @return     YES or NO.
 */
- (BOOL)writeBytesWithBlockIndex:(int)index
                       writeData:(NSData *)writeData
                             uid:(NSData *)uid;

@end
